<?php

add_action('parse_query', function(WP_Query $query) {
	$tecdoc = ep_tecdoc_service();
	if (isset($query->query_vars['vehicle_slug'])) {
		$tecdoc->setSelectedVehicle($query->query_vars['vehicle_slug']);
		return;
	}
});

/**
 * Dodajemo custom varijable u query.
 */
add_filter('query_vars', function($query_vars) {
	$query_vars[] = 'vehicle_slug';
	$query_vars[] = 'tecdoc_keys';
	return $query_vars;
});

/**
 * Definiramo slug vozila u url-u.
 */
add_filter('rewrite_rules_array', function($rules) {

	$permalinks = wc_get_permalink_structure();

	if (!isset($permalinks['category_rewrite_slug'], $permalinks['product_rewrite_slug'])) {
		return $rules;
	}

	$_rules = [];
	$_rules['([^/]+)/'. $permalinks['category_rewrite_slug'] . '/(.+)/page/(\d+)/?$'] = 'index.php?vehicle_slug=$matches[1]&product_cat=$matches[2]&paged=$matches[3]';
	$_rules['([^/]+)/'. $permalinks['category_rewrite_slug'] . '/(([^/]+)/?)+$'] = 'index.php?vehicle_slug=$matches[1]&product_cat=$matches[2]';

	if ($shopPageId = wc_get_page_id('shop')) {
		$slug = get_post_field('post_name', $shopPageId);
		$_rules['([^/]+)/'. $slug .'/?$'] = 'index.php?post_type=product&vehicle_slug=$matches[1]';
		$_rules['([^/]+)/'. $slug .'/page/([0-9]+)/?$'] = 'index.php?post_type=product&vehicle_slug=$matches[1]&paged=$matches[2]';
	}

	$rules = $_rules + $rules;

	return $rules;
});
/*
add_filter('page_link', function($link, $pageId) {

	if ($pageId == wc_get_page_id('shop')) {
		$tecdoc = ep_tecdoc_service();

		if ($vehicle = $tecdoc->getSelectedVehicle()) {
			$homeUrl = rtrim(get_option('home'), '/');
			$link = str_replace($homeUrl, $homeUrl . '/' . $vehicle['slug'], $link);
		}
	}

	return $link;
}, 10, 2);
*/
/**
 * Dodajemo slug vozila u url-ove kategorija.
 */
add_filter('term_link', function($url, WP_Term $term, $taxonomy) {

	if ('product_cat' === $taxonomy && ($vehicle = ep_tecdoc_service()->getSelectedVehicle())) {
		$homeUrl = rtrim(get_option('home'), '/');
		$url = str_replace($homeUrl, $homeUrl . '/' . $vehicle['slug'], $url);
	}

	return $url;
}, 10, 3);

/**
 * Provjeravamo da li imamo vozilo u url-u.
 */
add_action('template_redirect', function() {
	global $wp_query;

	if (!$wp_query->is_main_query()) {
		return;
	}

	$tecdoc = ep_tecdoc_service();

	if (isset($wp_query->query_vars['vehicle_slug'])) {
		$tecdoc->setSelectedVehicle($wp_query->query_vars['vehicle_slug']);
		return;
	}

	$vehicle = $tecdoc->getSelectedVehicle();

	if (!$vehicle) {
		return;
	}

	if (is_shop() && !is_search()) {
		$homeUrl = rtrim(get_option('home'), '/');
		$shopUrl = get_permalink(wc_get_page_id('shop'));
		$redirectUrl = str_replace($homeUrl, $homeUrl . '/' . $vehicle['slug'], $shopUrl);

		wp_redirect($redirectUrl, 301);
		exit;
	}
}, 9999);