<?php
namespace Ep\TecDoc;

use Ep\Cache\Service\CacheManager;
use Ep\Http\Service\HttpClientManager;
use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class TecDocServiceFactory
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class TecDocServiceFactory implements FactoryInterface
{
	/**
	 * @return TecDocService
	 */
	/**
	 * Create an object
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$config = $container->get('config')['tecdoc'] ?? [];
        $client = $container->get('http.tecdoc');
        $cache = $container->get('cache.tecdoc');

		return new TecDocService($config, $client, $cache);
	}
}